``io`` - Data In- and Output
----------------------------

This module exposes the generic file reader.

.. autoclass:: osmium.io.Reader
    :members:
    :undoc-members:

.. autoclass:: osmium.io.Header
    :members:
    :undoc-members:
